export var _isValidEmail = function (email) {
    var emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
};
export var _isValidPhoneNumber = function (phoneNumber) {
    var phoneRegex = /^\+?[0-9]{10,15}$/;
    return phoneRegex.test(phoneNumber);
};
export var _isValidURL = function (url) {
    var urlRegex = /^(https?:\/\/)?([a-zA-Z0-9.-]+)(:[0-9]{1,5})?(\/.*)?$/;
    return urlRegex.test(url);
};
export var _isValidDate = function (date) {
    var dateRegex = /^\d{4}-\d{2}-\d{2}$/;
    return dateRegex.test(date);
};
export var _isValidTime = function (time) {
    var timeRegex = /^([01]\d|2[0-3]):([0-5]\d)$/;
    return timeRegex.test(time);
};
export var _isValidDateTime = function (dateTime) {
    var dateTimeRegex = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}$/;
    return dateTimeRegex.test(dateTime);
};
export var _isValidDateRange = function (startDate, endDate) {
    return new Date(startDate) <= new Date(endDate);
};
export var _isValidPassword = function (password) {
    var passwordRegex = /^(?=.*[A-Za-z])(?=.*\d)[A-Za-z\d]{8,}$/;
    return passwordRegex.test(password);
};
export var _isValidUsername = function (username) {
    var usernameRegex = /^[a-zA-Z0-9._-]{3,}$/;
    return usernameRegex.test(username);
};
export var _isValidCreditCard = function (creditCard) {
    var creditCardRegex = /^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9]{2})[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|7(?:0[0-9]|[1-9][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$/;
    return creditCardRegex.test(creditCard);
};
export var _isValidHexColor = function (color) {
    var hexColorRegex = /^#([0-9A-F]{3}|[0-9A-F]{6})$/i;
    return hexColorRegex.test(color);
};
export var _isValidIP = function (ip) {
    var ipRegex = /^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
    return ipRegex.test(ip);
};
export var _isValidMacAddress = function (mac) {
    var macRegex = /^([0-9A-F]{2}[:-]){5}([0-9A-F]{2})$/i;
    return macRegex.test(mac);
};
export var _isValidUUID = function (uuid) {
    var uuidRegex = /^[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i;
    return uuidRegex.test(uuid);
};
export var _isValidBase64 = function (str) {
    var base64Regex = /^(?:[A-Z0-9+\/]{4})*=[=]?$/i;
    return base64Regex.test(str);
};
export var _isValidJSON = function (str) {
    try {
        JSON.parse(str);
        return true;
    }
    catch (_a) {
        return false;
    }
};
export var _isValidFunction = function (fn) {
    return typeof fn === 'function';
};
export var _isValidString = function (str) {
    return typeof str === 'string' && str.trim() !== '';
};
export var _isValidNumber = function (num) {
    return typeof num === 'number' && !isNaN(num);
};
export var _isValidBoolean = function (bool) {
    return typeof bool === 'boolean';
};
export var _isValidDateObject = function (date) {
    return date instanceof Date && !isNaN(date.getTime());
};
export var _isValidBlob = function (blob) {
    return blob instanceof Blob;
};
export var _isValidFile = function (file) {
    return file instanceof File;
};
export var _isValidRegExp = function (regex) {
    return regex instanceof RegExp;
};
export var _isValidPromise = function (promise) {
    return promise instanceof Promise;
};
export var _isValidDateString = function (dateString) {
    return !isNaN(Date.parse(dateString));
};
export var _isValidHTMLElement = function (element) {
    return element instanceof HTMLElement;
};
export var _isValidEvent = function (event) {
    return event instanceof Event;
};
export var _isValidNode = function (node) {
    return node instanceof Node;
};
export var _isValidNodeList = function (nodeList) {
    return nodeList instanceof NodeList;
};
export var _isValidHTMLCollection = function (htmlCollection) {
    return htmlCollection instanceof HTMLCollection;
};
export var _isValidFormData = function (formData) {
    return formData instanceof FormData;
};
export var _isValidURLSearchParams = function (params) {
    return params instanceof URLSearchParams;
};
export var _allowDecimalKeys = function (event) {
    // List of allowed non-character keys
    var allowedKeys = ['Backspace', 'Tab', 'ArrowLeft', 'ArrowRight', 'Delete', 'Home', 'End'];
    // Allow copy, paste, and other ctrl/cmd shortcuts
    if (event.ctrlKey || event.metaKey)
        return;
    // Allow the navigation keys and similar controls
    if (allowedKeys.includes(event.key))
        return;
    // Allow digits (0-9)
    if (/^\d$/.test(event.key))
        return;
    // Allow a decimal point only if there isn't one already in the input value
    if (event.key === '.') {
        if (event.target.value.includes('.')) {
            event.preventDefault();
        }
        return;
    }
    // For any other key, prevent the default behavior
    event.preventDefault();
};
export var _allowAlphaKeys = function (event) {
    // List of allowed non-character keys
    var allowedKeys = ['Backspace', 'Tab', 'ArrowLeft', 'ArrowRight', 'Delete', 'Home', 'End'];
    // Allow copy, paste, and other ctrl/cmd shortcuts
    if (event.ctrlKey || event.metaKey)
        return;
    // Allow the defined navigation and control keys
    if (allowedKeys.includes(event.key))
        return;
    // Allow alphabetical characters (both uppercase and lowercase)
    if (/^[a-zA-Z]$/.test(event.key))
        return;
    // For any other key, prevent its default behavior
    event.preventDefault();
};
export var _handlePasteDecimalKeys = function (a) {
    var b = a.clipboardData.getData("text");
    if (!/^-?\d+(\.\d+)?$/.test(b)) {
        a.preventDefault();
    }
};
export var _handlePasteAlphabetKeys = function (event) {
    var pastedText = event.clipboardData.getData("text");
    if (!/^[A-Za-z]+$/.test(pastedText)) {
        event.preventDefault();
    }
};
export var _allowAlphaNumericKeys = function (event) {
    var allowedKeys = ['Backspace', 'Tab', 'ArrowLeft', 'ArrowRight', 'Delete', 'Home', 'End'];
    // Allow copy, paste, etc. via Ctrl/Cmd shortcuts.
    if (event.ctrlKey || event.metaKey)
        return;
    // Allow navigation and control keys.
    if (allowedKeys.includes(event.key))
        return;
    // Allow alphanumeric characters (letters and digits).
    if (/^[A-Za-z0-9]$/.test(event.key))
        return;
    // Prevent any other key input.
    event.preventDefault();
};
export var _domSelector = function (selector, all) {
    if (all === void 0) { all = false; }
    if (typeof selector !== 'string' || !selector.trim()) {
        return all ? [] : null;
    }
    var result = all ? document === null || document === void 0 ? void 0 : document.querySelectorAll(selector) : document === null || document === void 0 ? void 0 : document.querySelector(selector);
    return result || (all ? [] : null);
};
export var _hideElement = function (selector) {
    var el = _domSelector(selector);
    if (el instanceof HTMLElement) {
        el.style.display = 'none';
    }
    else {
        console.warn("hideElement: Element not found for selector \"".concat(selector, "\""));
    }
};
export var _showElement = function (selector, displayType) {
    if (displayType === void 0) { displayType = 'block'; }
    var el = _domSelector(selector);
    if (el instanceof HTMLElement) {
        el.style.display = displayType;
    }
    else {
        console.warn("showElement: Element not found for selector \"".concat(selector, "\""));
    }
};
export var _removeElement = function (selector) {
    var element = document.querySelector(selector);
    if (element) {
        element.remove();
    }
};
export var _removeNode = function (selector) {
    document.querySelectorAll(selector).forEach(function (el) { return el.remove(); });
};
export var _removeSafeElement = function (selector) {
    var el = _domSelector(selector);
    if (el instanceof HTMLElement && el.parentNode) {
        el.parentNode.removeChild(el);
    }
    else {
        console.warn("removeElement: Element not found or has no parent for selector \"".concat(selector, "\""));
    }
};
export var _clearNode = function (baseSelector, targets) {
    var baseElement = document.querySelector(baseSelector);
    if (!baseElement)
        return;
    targets.forEach(function (_a) {
        var type = _a.type, steps = _a.steps;
        var element = baseElement;
        for (var i = 0; i < steps; i++) {
            if (!element)
                break;
            switch (type) {
                case 'previous':
                    element = element.previousSibling;
                    break;
                case 'next':
                    element = element.nextSibling;
                    break;
                case 'nextElement':
                    element = element instanceof Element ? element.nextElementSibling : null;
                    break;
            }
        }
        if (element && 'style' in element) {
            element.style.display = 'none';
        }
    });
};
export var _isElementPresent = function (selector) {
    return !!document.querySelector(selector);
};
export var _getParent = function (selector) {
    var element = document.querySelector(selector);
    return element ? element.parentElement : null;
};
export var _getChildElements = function (selector) {
    var element = document.querySelector(selector);
    return element ? Array.from(element.children) : [];
};
export var _replaceContent = function (selector, newContent) {
    var element = document.querySelector(selector);
    if (element) {
        element.innerHTML = newContent;
    }
};
export var _cloneElement = function (selector) {
    var element = document.querySelector(selector);
    return element ? element.cloneNode(true) : null;
};
export var _scrollToElement = function (selector, behavior) {
    if (behavior === void 0) { behavior = 'smooth'; }
    var element = document.querySelector(selector);
    if (element) {
        element.scrollIntoView({ behavior: behavior });
    }
};
export var _isElementInViewport = function (selector) {
    var element = document.querySelector(selector);
    if (!element)
        return false;
    var rect = element.getBoundingClientRect();
    return (rect.top >= 0 &&
        rect.left >= 0 &&
        rect.bottom <= window.innerHeight &&
        rect.right <= window.innerWidth);
};
export var _setElementDisabled = function (selector, isDisabled) {
    var element = document.querySelector(selector);
    if (element) {
        element.disabled = isDisabled;
    }
};
export var _addEventListenerToElement = function (selector, event, callback) {
    var element = document.querySelector(selector);
    if (element) {
        element.addEventListener(event, callback);
    }
};
export var _removeEventListenerFromElement = function (selector, event, callback) {
    var element = document.querySelector(selector);
    if (element) {
        element.removeEventListener(event, callback);
    }
};
export var _getElementAttribute = function (selector, attribute) {
    var element = document.querySelector(selector);
    return element ? element.getAttribute(attribute) : null;
};
export var _setElementAttribute = function (selector, attribute, value) {
    var element = document.querySelector(selector);
    if (element) {
        element.setAttribute(attribute, value);
    }
};
export var _removeElementAttribute = function (selector, attribute) {
    var element = document.querySelector(selector);
    if (element) {
        element.removeAttribute(attribute);
    }
};
export var _removeAllChildren = function (selector) {
    var element = document.querySelector(selector);
    if (element) {
        while (element.firstChild) {
            element.removeChild(element.firstChild);
        }
    }
};
export var _getElementsByClass = function (className) {
    return Array.from(document.getElementsByClassName(className));
};
export var _getElementsByTag = function (tagName) {
    return Array.from(document.getElementsByTagName(tagName));
};
export var _setMultipleStyles = function (selector, styles) {
    var element = document.querySelector(selector);
    if (element) {
        Object.assign(element.style, styles);
    }
};
export var _insertHTML = function (selector, position, html) {
    var element = document.querySelector(selector);
    if (element) {
        element.insertAdjacentHTML(position, html);
    }
};
export var _isDocumentLoaded = function () {
    return document.readyState === 'complete';
};
export var _runOnIframeLoad = function (iframeSelector, callback) {
    var iframe = document.querySelector(iframeSelector);
    if (iframe) {
        iframe.addEventListener('load', callback);
    }
};
export var _reloadAfterLoad = function (delay) {
    if (delay === void 0) { delay = 3000; }
    window.addEventListener('load', function () {
        setTimeout(function () { return window.location.reload(); }, delay);
    });
};
